@@ -58,7 +58,8 @@ var menudata={children:[
 {text:"y",url:"namespacemembers_y.html#index_y"},
 {text:"z",url:"namespacemembers_z.html#index_z"}]},
 {text:"Functions",url:"namespacemembers_func.html",children:[
-{text:"b",url:"namespacemembers_func.html#index_b"},
+{text:"a",url:"namespacemembers_func.html#index_a"},
+{text:"b",url:"namespacemembers_func_b.html#index_b"},
 {text:"c",url:"namespacemembers_func_c.html#index_c"},
 {text:"d",url:"namespacemembers_func_d.html#index_d"},
 {text:"e",url:"namespacemembers_func_e.html#index_e"},
@@ -85,6 +86,7 @@ var menudata={children:[
 {text:"e",url:"namespacemembers_vars.html#index_e"},
 {text:"f",url:"namespacemembers_vars.html#index_f"},
 {text:"g",url:"namespacemembers_vars.html#index_g"},
+{text:"h",url:"namespacemembers_vars.html#index_h"},
 {text:"i",url:"namespacemembers_vars.html#index_i"},
 {text:"l",url:"namespacemembers_vars.html#index_l"},
 {text:"m",url:"namespacemembers_vars.html#index_m"},
@@ -98,6 +100,7 @@ var menudata={children:[
 {text:"c",url:"namespacemembers_type.html#index_c"},
 {text:"d",url:"namespacemembers_type.html#index_d"},
 {text:"e",url:"namespacemembers_type.html#index_e"},
+{text:"f",url:"namespacemembers_type.html#index_f"},
 {text:"g",url:"namespacemembers_type.html#index_g"},
 {text:"h",url:"namespacemembers_type.html#index_h"},
 {text:"i",url:"namespacemembers_type.html#index_i"},
@@ -229,8 +232,7 @@ var menudata={children:[
 {text:"y",url:"functions_vars_y.html#index_y"},
 {text:"z",url:"functions_vars_z.html#index_z"}]},
 {text:"Typedefs",url:"functions_type.html",children:[
-{text:"_",url:"functions_type.html#index__5F"},
-{text:"a",url:"functions_type_a.html#index_a"},
+{text:"a",url:"functions_type.html#index_a"},
 {text:"b",url:"functions_type_b.html#index_b"},
 {text:"c",url:"functions_type_c.html#index_c"},
 {text:"d",url:"functions_type_d.html#index_d"},
@@ -308,7 +310,7 @@ var menudata={children:[
 {text:"y",url:"functions_eval_y.html#index_y"},
 {text:"z",url:"functions_eval_z.html#index_z"}]},
 {text:"Properties",url:"functions_prop.html"},
-{text:"Related Functions",url:"functions_rela.html",children:[
+{text:"Related Symbols",url:"functions_rela.html",children:[
 {text:":",url:"functions_rela.html#index_:"},
 {text:"a",url:"functions_rela_a.html#index_a"},
 {text:"b",url:"functions_rela_b.html#index_b"},
@@ -346,6 +348,7 @@ var menudata={children:[
 {text:"g",url:"globals_g.html#index_g"},
 {text:"h",url:"globals_h.html#index_h"},
 {text:"i",url:"globals_i.html#index_i"},
+{text:"k",url:"globals_k.html#index_k"},
 {text:"l",url:"globals_l.html#index_l"},
 {text:"m",url:"globals_m.html#index_m"},
 {text:"n",url:"globals_n.html#index_n"},
@@ -386,25 +389,36 @@ var menudata={children:[
 {text:"y",url:"globals_func_y.html#index_y"}]},
 {text:"Variables",url:"globals_vars.html",children:[
 {text:"a",url:"globals_vars.html#index_a"},
-{text:"c",url:"globals_vars.html#index_c"},
-{text:"d",url:"globals_vars.html#index_d"},
-{text:"e",url:"globals_vars.html#index_e"},
-{text:"f",url:"globals_vars.html#index_f"},
-{text:"g",url:"globals_vars.html#index_g"},
-{text:"h",url:"globals_vars.html#index_h"},
-{text:"l",url:"globals_vars.html#index_l"},
-{text:"m",url:"globals_vars.html#index_m"},
-{text:"o",url:"globals_vars.html#index_o"},
-{text:"p",url:"globals_vars.html#index_p"},
-{text:"t",url:"globals_vars.html#index_t"},
-{text:"v",url:"globals_vars.html#index_v"},
-{text:"x",url:"globals_vars.html#index_x"},
-{text:"y",url:"globals_vars.html#index_y"}]},
+{text:"b",url:"globals_vars_b.html#index_b"},
+{text:"c",url:"globals_vars_c.html#index_c"},
+{text:"d",url:"globals_vars_d.html#index_d"},
+{text:"e",url:"globals_vars_e.html#index_e"},
+{text:"f",url:"globals_vars_f.html#index_f"},
+{text:"g",url:"globals_vars_g.html#index_g"},
+{text:"h",url:"globals_vars_h.html#index_h"},
+{text:"k",url:"globals_vars_k.html#index_k"},
+{text:"l",url:"globals_vars_l.html#index_l"},
+{text:"m",url:"globals_vars_m.html#index_m"},
+{text:"n",url:"globals_vars_n.html#index_n"},
+{text:"o",url:"globals_vars_o.html#index_o"},
+{text:"p",url:"globals_vars_p.html#index_p"},
+{text:"r",url:"globals_vars_r.html#index_r"},
+{text:"s",url:"globals_vars_s.html#index_s"},
+{text:"t",url:"globals_vars_t.html#index_t"},
+{text:"u",url:"globals_vars_u.html#index_u"},
+{text:"v",url:"globals_vars_v.html#index_v"},
+{text:"w",url:"globals_vars_w.html#index_w"},
+{text:"x",url:"globals_vars_x.html#index_x"},
+{text:"y",url:"globals_vars_y.html#index_y"},
+{text:"z",url:"globals_vars_z.html#index_z"}]},
 {text:"Typedefs",url:"globals_type.html",children:[
 {text:"a",url:"globals_type.html#index_a"},
+{text:"b",url:"globals_type_b.html#index_b"},
 {text:"c",url:"globals_type_c.html#index_c"},
+{text:"d",url:"globals_type_d.html#index_d"},
 {text:"e",url:"globals_type_e.html#index_e"},
 {text:"f",url:"globals_type_f.html#index_f"},
+{text:"h",url:"globals_type_h.html#index_h"},
 {text:"i",url:"globals_type_i.html#index_i"},
 {text:"l",url:"globals_type_l.html#index_l"},
 {text:"m",url:"globals_type_m.html#index_m"},
@@ -419,6 +433,7 @@ var menudata={children:[
 {text:"x",url:"globals_type_x.html#index_x"},
 {text:"z",url:"globals_type_z.html#index_z"}]},
 {text:"Enumerations",url:"globals_enum.html",children:[
+{text:"d",url:"globals_enum.html#index_d"},
 {text:"e",url:"globals_enum.html#index_e"},
 {text:"i",url:"globals_enum.html#index_i"},
 {text:"p",url:"globals_enum.html#index_p"},
@@ -429,6 +444,7 @@ var menudata={children:[
 {text:"Enumerator",url:"globals_eval.html",children:[
 {text:"b",url:"globals_eval.html#index_b"},
 {text:"c",url:"globals_eval_c.html#index_c"},
+{text:"d",url:"globals_eval_d.html#index_d"},
 {text:"i",url:"globals_eval_i.html#index_i"},
 {text:"n",url:"globals_eval_n.html#index_n"},
 {text:"p",url:"globals_eval_p.html#index_p"},
@@ -460,5 +476,6 @@ var menudata={children:[
 {text:"u",url:"globals_defs_u.html#index_u"},
 {text:"v",url:"globals_defs_v.html#index_v"},
 {text:"w",url:"globals_defs_w.html#index_w"},
+{text:"x",url:"globals_defs_x.html#index_x"},
 {text:"y",url:"globals_defs_y.html#index_y"},
 {text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}
